@@ -4,7 +4,7 @@
  * dialects and quoting.
  *
  * Copyright 2007 Maintainable Software, LLC
- * Copyright 2008-2011 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2012 Horde LLC (http://www.horde.org/)
  *
  * @author     Mike Naberezny <mike@maintainable.com>
  * @author     Derek DeVries <derek@maintainable.com>
@@ -98,7 +98,7 @@ class Horde_Db_Adapter_Sqlite_Schema extends Horde_Db_Adapter_Base_Schema
      */
     public function quoteBinary($value)
     {
-        return "'" . str_replace(array('%', "\0"), array('%25', '%00'), $value) . "'";
+        return "'" . str_replace(array("'", '%', "\0"), array("''", '%25', '%00'), $value) . "'";
     }
 
 
@@ -382,8 +382,6 @@ class Horde_Db_Adapter_Sqlite_Schema extends Horde_Db_Adapter_Base_Schema
     /**
      * Adds a primary key to a table.
      *
-     * @since Horde_Db 1.1.0
-     *
      * @param string $tableName         A table name.
      * @param string|array $columnName  One or more column names.
      *
@@ -406,8 +404,6 @@ class Horde_Db_Adapter_Sqlite_Schema extends Horde_Db_Adapter_Base_Schema
     /**
      * Removes a primary key from a table.
      *
-     * @since Horde_Db 1.1.0
-     *
      * @param string $tableName  A table name.
      *
      * @throws Horde_Db_Exception
@@ -479,11 +475,11 @@ class Horde_Db_Adapter_Sqlite_Schema extends Horde_Db_Adapter_Base_Schema
     /**
      * Generates a modified date for SELECT queries.
      *
-     * @since Horde_Db 1.2.0
-     *
-     * @param string $reference  The reference date.
-     * @param string $operator   The oprator for the modification (+/-)
-     * @param string $amount     The modification amount.
+     * @param string $reference  The reference date - this is a column
+     *                           referenced in the SELECT.
+     * @param string $operator   Add or subtract time? (+/-)
+     * @param integer $amount    The shift amount (number of days if $interval
+     *                           is DAY, etc).
      * @param string $interval   The interval (SECOND, MINUTE, HOUR, DAY,
      *                           MONTH, YEAR).
      *
@@ -491,7 +487,10 @@ class Horde_Db_Adapter_Sqlite_Schema extends Horde_Db_Adapter_Base_Schema
      */
     public function modifyDate($reference, $operator, $amount, $interval)
     {
-        switch($interval) {
+        if (!is_int($amount)) {
+            throw new InvalidArgumentException('$amount parameter must be an integer');
+        }
+        switch ($interval) {
         case 'YEAR':
             $interval = 'years';
             break;
@@ -513,6 +512,7 @@ class Horde_Db_Adapter_Sqlite_Schema extends Horde_Db_Adapter_Base_Schema
         default:
             break;
         }
+
         return 'datetime(' . $reference . ', \'' . $operator . $amount . ' '
             . $interval . '\')';
     }
